@@ -1,10 +1,10 @@
 import argparse
-import sys
 from typing import List, Optional
 
-from nix_prefetch_github.repository import GithubRepository
+from nix_prefetch_github.interfaces import GithubRepository
 
 from ..dependency_injector import DependencyInjector
+from ..use_cases.prefetch_latest_release import Request
 from .arguments import get_options_argument_parser
 
 
@@ -14,17 +14,14 @@ def main(args: Optional[List[str]] = None) -> None:
         logging_configuration=arguments.logging_configuration,
         rendering_format=arguments.rendering_format,
     )
-    presenter = injector.get_presenter()
-    repository = GithubRepository(owner=arguments.owner, name=arguments.repo)
-    prefetch_options = arguments.prefetch_options
-    github_api = injector.get_github_api()
-    prefetcher = injector.get_prefetcher()
-    prefetched_repository = prefetcher.prefetch_github(
-        repository,
-        rev=github_api.get_tag_of_latest_release(repository),
-        prefetch_options=prefetch_options,
+    use_case = injector.get_prefetch_latest_release_use_case()
+    use_case.prefetch_latest_release(
+        request=Request(
+            repository=GithubRepository(owner=arguments.owner, name=arguments.repo),
+            prefetch_options=arguments.prefetch_options,
+            rendering_format=arguments.rendering_format,
+        )
     )
-    sys.exit(presenter.present(prefetched_repository))
 
 
 def parse_arguments(arguments: Optional[List[str]]) -> argparse.Namespace:
