@@ -5,16 +5,16 @@ from logging import Logger
 from .command.command_availability_checker import CommandAvailabilityCheckerImpl
 from .command.command_runner import CommandRunnerImpl
 from .github import GithubAPIImpl
-from .interfaces import GithubAPI, RepositoryDetector, RevisionIndexFactory, UrlHasher
+from .interfaces import (
+    GithubAPI,
+    RenderingFormat,
+    RepositoryDetector,
+    RevisionIndexFactory,
+)
 from .list_remote_factory import ListRemoteFactoryImpl
 from .logging import LoggingConfiguration, get_logger
 from .prefetch import PrefetcherImpl
-from .presenter import (
-    Presenter,
-    RenderingFormat,
-    RepositoryRenderer,
-    get_renderer_from_rendering_format,
-)
+from .presenter import JsonRepositoryRenderer, NixRepositoryRenderer, PresenterImpl
 from .repository_detector import RepositoryDetectorImpl
 from .revision_index_factory import RevisionIndexFactoryImpl
 from .url_hasher.nix_build import NixBuildUrlHasherImpl
@@ -23,6 +23,9 @@ from .url_hasher.url_hasher_selector import (
     CommandAvailabilityChecker,
     UrlHasherSelector,
 )
+from .use_cases.prefetch_directory import PrefetchDirectoryUseCase
+from .use_cases.prefetch_github_repository import PrefetchGithubRepositoryUseCase
+from .use_cases.prefetch_latest_release import PrefetchLatestReleaseUseCase
 
 
 class DependencyInjector:
@@ -60,22 +63,16 @@ class DependencyInjector:
             command_runner=self.get_command_runner(), logger=self.get_logger()
         )
 
-    def get_url_hasher(self) -> UrlHasher:
-        selector = self.get_url_hasher_selector()
-        return selector.get_url_hasher()
-
     def get_prefetcher(self) -> PrefetcherImpl:
-        return PrefetcherImpl(self.get_url_hasher(), self.get_revision_index_factory())
-
-    def get_presenter(self) -> Presenter:
-        return Presenter(
-            result_output=sys.stdout,
-            error_output=sys.stderr,
-            repository_renderer=self.get_repository_renderer(),
+        return PrefetcherImpl(
+            self.get_url_hasher_selector(), self.get_revision_index_factory()
         )
 
-    def get_repository_renderer(self) -> RepositoryRenderer:
-        return get_renderer_from_rendering_format(self._rendering_format)
+    def get_nix_repository_renderer(self) -> NixRepositoryRenderer:
+        return NixRepositoryRenderer()
+
+    def get_json_repository_renderer(self) -> JsonRepositoryRenderer:
+        return JsonRepositoryRenderer()
 
     def get_github_api(self) -> GithubAPI:
         return GithubAPIImpl()
@@ -92,3 +89,43 @@ class DependencyInjector:
 
     def get_logging_configuration(self) -> LoggingConfiguration:
         return self._logging_configuration
+
+    def get_nix_presenter(self) -> PresenterImpl:
+        return PresenterImpl(
+            result_output=sys.stdout,
+            error_output=sys.stderr,
+            repository_renderer=self.get_nix_repository_renderer(),
+        )
+
+    def get_json_presenter(self) -> PresenterImpl:
+        return PresenterImpl(
+            result_output=sys.stdout,
+            error_output=sys.stderr,
+            repository_renderer=self.get_json_repository_renderer(),
+        )
+
+    def get_prefetch_latest_release_use_case(self) -> PrefetchLatestReleaseUseCase:
+        return PrefetchLatestReleaseUseCase(
+            nix_presenter=self.get_nix_presenter(),
+            json_presenter=self.get_json_presenter(),
+            prefetcher=self.get_prefetcher(),
+            github_api=self.get_github_api(),
+        )
+
+    def get_prefetch_github_repository_use_case(
+        self,
+    ) -> PrefetchGithubRepositoryUseCase:
+        return PrefetchGithubRepositoryUseCase(
+            nix_presenter=self.get_nix_presenter(),
+            json_presenter=self.get_json_presenter(),
+            prefetcher=self.get_prefetcher(),
+        )
+
+    def get_prefetch_directory_use_case(self) -> PrefetchDirectoryUseCase:
+        return PrefetchDirectoryUseCase(
+            nix_presenter=self.get_nix_presenter(),
+            json_presenter=self.get_json_presenter(),
+            prefetcher=self.get_prefetcher(),
+            repository_detector=self.get_repository_detector(),
+            logger=self.get_logger(),
+        )
