@@ -2,11 +2,19 @@ import enum
 from dataclasses import dataclass
 from typing import Dict, List, Optional, Protocol, Tuple, Union
 
-from .list_remote import ListRemote
-from .repository import GithubRepository
-from .revision_index import RevisionIndex
 
-trash_sha256 = "1y4ly7lgqm03wap4mh01yzcmvryp29w739fy07zzvz15h2z9x3dv"
+class RevisionIndex(Protocol):
+    def get_revision_by_name(self, name: str) -> Optional[str]:
+        ...
+
+
+@dataclass(frozen=True)
+class GithubRepository:
+    owner: str
+    name: str
+
+    def url(self) -> str:
+        return f"https://github.com/{self.owner}/{self.name}.git"
 
 
 @dataclass
@@ -51,11 +59,6 @@ class RepositoryDetector(Protocol):
         ...
 
 
-class ListRemoteFactory(Protocol):
-    def get_list_remote(self, repository: GithubRepository) -> Optional[ListRemote]:
-        pass
-
-
 @dataclass(frozen=True)
 class PrefetchedRepository:
     repository: GithubRepository
@@ -106,3 +109,19 @@ class CommandRunner(Protocol):
 class CommandAvailabilityChecker(Protocol):
     def is_command_available(self, command: str) -> bool:
         ...
+
+
+class RepositoryRenderer(Protocol):
+    def render_prefetched_repository(self, repository: PrefetchedRepository) -> str:
+        ...
+
+
+class Presenter(Protocol):
+    def present(self, prefetch_result: PrefetchResult) -> int:
+        ...
+
+
+@enum.unique
+class RenderingFormat(enum.Enum):
+    nix = enum.auto()
+    json = enum.auto()
