@@ -2,7 +2,7 @@ from logging import getLogger
 from unittest import TestCase
 
 from ..command.command_runner import CommandRunnerImpl
-from ..repository import GithubRepository
+from ..interfaces import GithubRepository
 from ..tests import network, requires_nix_build
 from .nix_build import (
     NixBuildUrlHasherImpl,
